###################################################################################################
# _acl_mediadb.py
#
# Implementation of class MediaDb (see below).
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
###################################################################################################

# Imports.
from Globals import HTMLFile
from Globals import MessageDialog
from Globals import Persistent   
import OFS.SimpleItem
import Acquisition
import AccessControl.Role
import urllib
import string
import time
# Product Imports.
import _fileutil


###################################################################################################
###################################################################################################
###   
###   C o n s t r u c t o r ( s )
###   
###################################################################################################
###################################################################################################
manage_addMediaDbForm = HTMLFile('manage_addmediadbform', globals()) 
def manage_addMediaDb(self, location, REQUEST=None, RESPONSE=None):
  """ manage_addMediaDb """
  
  # Create mediadb.
  obj = MediaDb(location)
  self._setObject(obj.id, obj)
  
  # Return.
  if RESPONSE is not None:
    RESPONSE.redirect('%s/manage_main'%self.absolute_url())



###################################################################################################
###################################################################################################
###
###   C l a s s   M e d i a D b
###
###################################################################################################
###################################################################################################
class MediaDb(
    OFS.SimpleItem.Item,
    Persistent,
    Acquisition.Implicit,
    AccessControl.Role.RoleManager
    ): 

    # Properties.
    # -----------
    meta_type = 'MediaDb'

    # Management Options.
    # -------------------
    manage_options = (
	{'label': 'Edit','action': 'manage_browse'},
	{'label': 'Properties','action': 'manage_properties'},
        ) 

    manage_index_html = HTMLFile('dtml/acl_mediadb/manage_index', globals())
    manage_browse = HTMLFile('dtml/acl_mediadb/manage_browse', globals())
    manage_properties = HTMLFile('dtml/acl_mediadb/manage_properties', globals())

    """
    ###############################################################################################    
    #
    #   CONSTRUCTOR
    #
    ###############################################################################################    
    """

    ###############################################################################################
    #  MediaDb.__init__: 
    #
    #  Initialise a new instance of MediaDb.
    ###############################################################################################
    def __init__(self, location):
      self.id = 'acl_mediadb'
      self.location = location
      _fileutil.mkDir(location)


    # ---------------------------------------------------------------------------------------------
    #	MediaDb.urlQuote
    # ---------------------------------------------------------------------------------------------
    def urlQuote(self, s): 
      return urllib.quote(s)

    # ---------------------------------------------------------------------------------------------
    #	MediaDb.getPath
    # ---------------------------------------------------------------------------------------------
    def getPath(self, REQUEST): 
      path = REQUEST.get('path','')
      if len(path) < len(self.location):
        path = self.location
      return path

    # ---------------------------------------------------------------------------------------------
    #	MediaDb.readDir
    # ---------------------------------------------------------------------------------------------
    def readDir(self, path): 
      return _fileutil.readDir(path)

    # ---------------------------------------------------------------------------------------------
    #	MediaDb.getParentDir
    # ---------------------------------------------------------------------------------------------
    def getParentDir(self, path): 
      return _fileutil.getFilePath(path)
      
    # ---------------------------------------------------------------------------------------------
    #	MediaDb.getDateStr
    # ---------------------------------------------------------------------------------------------
    def getDateStr(self, tTime, sFmt='DATETIME_FMT'):
      dateFmt = {
      	   'TIME_FMT':'%H:%M:%S',
      	   'DATE_FMT':'%Y/%m/%d',
      	   'DATETIME_FMT':'%Y/%m/%d %H:%M:%S',
      	  }
      try:
        s = time.strftime(dateFmt[sFmt],time.localtime(tTime))
      except:
        s = str(tTime)
      return s

    # ---------------------------------------------------------------------------------------------
    #	MediaDb.getDataSizeStr
    # ---------------------------------------------------------------------------------------------
    def getDataSizeStr(self, len): 
      return _fileutil.getDataSizeStr(len)

    # ---------------------------------------------------------------------------------------------
    #	MediaDb.getFile
    # ---------------------------------------------------------------------------------------------
    def getFile(self, REQUEST,RESPONSE): 
      path = self.getPath(REQUEST)       
      RESPONSE.setHeader('Content-Type','Unknown')
      RESPONSE.setHeader('Content-Disposition','inline;filename=%s'%_fileutil.extractFileName(path))
      file = open(path,'rb')
      rtn = file.read() 
      file.close()
      return rtn

    # ---------------------------------------------------------------------------------------------
    #	MediaDb.storeFile
    # ---------------------------------------------------------------------------------------------
    def storeFile(self, file):
      filename = _fileutil.extractFileName(file.filename)
      fileext = _fileutil.extractFileExt(file.filename)
      filename = filename[:-(len(fileext)+1)] + '_' + string.replace(str(time.time()),'.','') + '.' + fileext
      filepath = _fileutil.getOSPath('%s/%s'%(self.location,filename))
      #++ print '[%s.storeFile] filepath=%s'%(self.meta_type,filepath)
      _fileutil.exportObj(file,filepath)
      return filename

    # ---------------------------------------------------------------------------------------------
    #	MediaDb.retrieveFile
    # ---------------------------------------------------------------------------------------------
    def retrieveFile(self, filename):
      try:
        filepath = _fileutil.getOSPath('%s/%s'%(self.location,filename))
        #++ print '[%s.retrieveFile] filepath=%s'%(self.meta_type,filepath)
        f = open(filepath,'rb')
        data = f.read()
        f.close()
      except:
        data = ''
      return data

    """
    ###############################################################################################    
    #
    #   PROPERTIES
    #
    ###############################################################################################    
    """

    ###############################################################################################
    #  MediaDb.manage_changeProperties: 
    #
    #  Change MediaDb properties.
    ###############################################################################################
    def manage_changeProperties(self, submit, REQUEST, RESPONSE): 
      """ MediaDb.manage_changeProperties """
      
      message = ''

      # Pack.
      if submit == 'Pack':
        pass
        
      # Return.
      if RESPONSE is not None:
        RESPONSE.redirect('manage_properties?manage_tabs_message=%s'%urllib.quote(message))

###################################################################################################
